| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Telegram.Bot.API.Types.Common
Synopsis
- newtype FileId = FileId Text
- newtype Seconds = Seconds Int
- newtype UserId = UserId Integer
- newtype BoostId = BoostId Text
- newtype ChatId = ChatId Integer
- newtype MessageId = MessageId Integer
- newtype MessageThreadId = MessageThreadId Integer
- newtype InlineMessageId = InlineMessageId Text
- newtype MediaGroupId = MediaGroupId Text
- newtype RequestId = RequestId Integer
- newtype PollId = PollId Text
- newtype ShippingOptionId = ShippingOptionId Text
- data WebAppInfo = WebAppInfo {}
- newtype CallbackQueryId = CallbackQueryId Text
- newtype BusinessConnectionId = BusinessConnectionId Text
- data SomeChatId
- addType :: Text -> [Pair] -> [Pair]
Documentation
Unique identifier for this file.
Instances
| FromJSON FileId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToJSON FileId Source # | |
| Show FileId Source # | |
| Eq FileId Source # | |
| ToHttpApiData FileId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: FileId -> Text # toEncodedUrlPiece :: FileId -> Builder # toHeader :: FileId -> ByteString # toQueryParam :: FileId -> Text # toEncodedQueryParam :: FileId -> Builder # | |
Unique identifier for this user or bot.
Instances
| FromJSON UserId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToJSON UserId Source # | |
| Show UserId Source # | |
| Eq UserId Source # | |
| ToHttpApiData UserId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: UserId -> Text # toEncodedUrlPiece :: UserId -> Builder # toHeader :: UserId -> ByteString # toQueryParam :: UserId -> Text # toEncodedQueryParam :: UserId -> Builder # | |
Unique identifier of the boost.
Instances
| FromJSON BoostId Source # | |||||
Defined in Telegram.Bot.API.Types.Common | |||||
| ToJSON BoostId Source # | |||||
| Generic BoostId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Associated Types
| |||||
| Show BoostId Source # | |||||
| Eq BoostId Source # | |||||
| type Rep BoostId Source # | |||||
Defined in Telegram.Bot.API.Types.Common | |||||
Unique identifier for this chat.
Instances
| FromJSON ChatId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToJSON ChatId Source # | |
| Show ChatId Source # | |
| Eq ChatId Source # | |
| Hashable ChatId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToHttpApiData ChatId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: ChatId -> Text # toEncodedUrlPiece :: ChatId -> Builder # toHeader :: ChatId -> ByteString # toQueryParam :: ChatId -> Text # toEncodedQueryParam :: ChatId -> Builder # | |
Unique message identifier inside this chat.
Instances
| FromJSON MessageId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToJSON MessageId Source # | |
| Show MessageId Source # | |
| Eq MessageId Source # | |
| Hashable MessageId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToHttpApiData MessageId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: MessageId -> Text # toEncodedUrlPiece :: MessageId -> Builder # toHeader :: MessageId -> ByteString # toQueryParam :: MessageId -> Text # toEncodedQueryParam :: MessageId -> Builder # | |
newtype MessageThreadId Source #
Unique identifier of a message thread to which the message belongs; for supergroups only.
Constructors
| MessageThreadId Integer |
Instances
newtype InlineMessageId Source #
Constructors
| InlineMessageId Text |
Instances
| FromJSON InlineMessageId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods parseJSON :: Value -> Parser InlineMessageId # parseJSONList :: Value -> Parser [InlineMessageId] # | |
| ToJSON InlineMessageId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: InlineMessageId -> Value # toEncoding :: InlineMessageId -> Encoding # toJSONList :: [InlineMessageId] -> Value # toEncodingList :: [InlineMessageId] -> Encoding # omitField :: InlineMessageId -> Bool # | |
| Show InlineMessageId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> InlineMessageId -> ShowS # show :: InlineMessageId -> String # showList :: [InlineMessageId] -> ShowS # | |
| Eq InlineMessageId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods (==) :: InlineMessageId -> InlineMessageId -> Bool # (/=) :: InlineMessageId -> InlineMessageId -> Bool # | |
| Hashable InlineMessageId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
newtype MediaGroupId Source #
The unique identifier of a media message group a message belongs to.
Constructors
| MediaGroupId Text |
Instances
| FromJSON MediaGroupId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
| ToJSON MediaGroupId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: MediaGroupId -> Value # toEncoding :: MediaGroupId -> Encoding # toJSONList :: [MediaGroupId] -> Value # toEncodingList :: [MediaGroupId] -> Encoding # omitField :: MediaGroupId -> Bool # | |
| Show MediaGroupId Source # | |
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> MediaGroupId -> ShowS # show :: MediaGroupId -> String # showList :: [MediaGroupId] -> ShowS # | |
| Eq MediaGroupId Source # | |
Defined in Telegram.Bot.API.Types.Common | |
Signed 32-bit identifier of the request, which will be received back in the UserShared or ChatShared object. Must be unique within the message.
Unique poll identifier.
newtype ShippingOptionId Source #
Constructors
| ShippingOptionId Text |
Instances
data WebAppInfo Source #
Constructors
| WebAppInfo | |
Fields | |
Instances
| FromJSON WebAppInfo Source # | |||||
Defined in Telegram.Bot.API.Types.Common | |||||
| ToJSON WebAppInfo Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: WebAppInfo -> Value # toEncoding :: WebAppInfo -> Encoding # toJSONList :: [WebAppInfo] -> Value # toEncodingList :: [WebAppInfo] -> Encoding # omitField :: WebAppInfo -> Bool # | |||||
| Generic WebAppInfo Source # | |||||
Defined in Telegram.Bot.API.Types.Common Associated Types
| |||||
| Show WebAppInfo Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> WebAppInfo -> ShowS # show :: WebAppInfo -> String # showList :: [WebAppInfo] -> ShowS # | |||||
| type Rep WebAppInfo Source # | |||||
Defined in Telegram.Bot.API.Types.Common type Rep WebAppInfo = D1 ('MetaData "WebAppInfo" "Telegram.Bot.API.Types.Common" "telegram-bot-api-7.4.5-5dPKIbH7RBmIytHX2MOrgE" 'False) (C1 ('MetaCons "WebAppInfo" 'PrefixI 'True) (S1 ('MetaSel ('Just "webAppInfoUrl") 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
newtype CallbackQueryId Source #
Constructors
| CallbackQueryId Text |
Instances
| FromJSON CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods parseJSON :: Value -> Parser CallbackQueryId # parseJSONList :: Value -> Parser [CallbackQueryId] # | |||||
| ToJSON CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: CallbackQueryId -> Value # toEncoding :: CallbackQueryId -> Encoding # toJSONList :: [CallbackQueryId] -> Value # toEncodingList :: [CallbackQueryId] -> Encoding # omitField :: CallbackQueryId -> Bool # | |||||
| Generic CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Associated Types
Methods from :: CallbackQueryId -> Rep CallbackQueryId x # to :: Rep CallbackQueryId x -> CallbackQueryId # | |||||
| Show CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> CallbackQueryId -> ShowS # show :: CallbackQueryId -> String # showList :: [CallbackQueryId] -> ShowS # | |||||
| Eq CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods (==) :: CallbackQueryId -> CallbackQueryId -> Bool # (/=) :: CallbackQueryId -> CallbackQueryId -> Bool # | |||||
| type Rep CallbackQueryId Source # | |||||
Defined in Telegram.Bot.API.Types.Common type Rep CallbackQueryId = D1 ('MetaData "CallbackQueryId" "Telegram.Bot.API.Types.Common" "telegram-bot-api-7.4.5-5dPKIbH7RBmIytHX2MOrgE" 'True) (C1 ('MetaCons "CallbackQueryId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
newtype BusinessConnectionId Source #
Unique identifier of the business connection.
Constructors
| BusinessConnectionId Text |
Instances
| FromJSON BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods parseJSON :: Value -> Parser BusinessConnectionId # parseJSONList :: Value -> Parser [BusinessConnectionId] # | |||||
| ToJSON BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: BusinessConnectionId -> Value # toEncoding :: BusinessConnectionId -> Encoding # toJSONList :: [BusinessConnectionId] -> Value # toEncodingList :: [BusinessConnectionId] -> Encoding # omitField :: BusinessConnectionId -> Bool # | |||||
| Generic BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Associated Types
Methods from :: BusinessConnectionId -> Rep BusinessConnectionId x # to :: Rep BusinessConnectionId x -> BusinessConnectionId # | |||||
| Show BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> BusinessConnectionId -> ShowS # show :: BusinessConnectionId -> String # showList :: [BusinessConnectionId] -> ShowS # | |||||
| Eq BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods (==) :: BusinessConnectionId -> BusinessConnectionId -> Bool # (/=) :: BusinessConnectionId -> BusinessConnectionId -> Bool # | |||||
| ToHttpApiData BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: BusinessConnectionId -> Text # toEncodedUrlPiece :: BusinessConnectionId -> Builder # toHeader :: BusinessConnectionId -> ByteString # | |||||
| type Rep BusinessConnectionId Source # | |||||
Defined in Telegram.Bot.API.Types.Common type Rep BusinessConnectionId = D1 ('MetaData "BusinessConnectionId" "Telegram.Bot.API.Types.Common" "telegram-bot-api-7.4.5-5dPKIbH7RBmIytHX2MOrgE" 'True) (C1 ('MetaCons "BusinessConnectionId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||
data SomeChatId Source #
Unique identifier for the target chat
or username of the target channel (in the format @channelusername).
Constructors
| SomeChatId ChatId | Unique chat ID. |
| SomeChatUsername Text | Username of the target channel. |
Instances
| FromJSON SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common | |||||
| ToJSON SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toJSON :: SomeChatId -> Value # toEncoding :: SomeChatId -> Encoding # toJSONList :: [SomeChatId] -> Value # toEncodingList :: [SomeChatId] -> Encoding # omitField :: SomeChatId -> Bool # | |||||
| Generic SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Associated Types
| |||||
| Show SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods showsPrec :: Int -> SomeChatId -> ShowS # show :: SomeChatId -> String # showList :: [SomeChatId] -> ShowS # | |||||
| ToHttpApiData SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common Methods toUrlPiece :: SomeChatId -> Text # toEncodedUrlPiece :: SomeChatId -> Builder # toHeader :: SomeChatId -> ByteString # toQueryParam :: SomeChatId -> Text # | |||||
| type Rep SomeChatId Source # | |||||
Defined in Telegram.Bot.API.Types.Common type Rep SomeChatId = D1 ('MetaData "SomeChatId" "Telegram.Bot.API.Types.Common" "telegram-bot-api-7.4.5-5dPKIbH7RBmIytHX2MOrgE" 'False) (C1 ('MetaCons "SomeChatId" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 ChatId)) :+: C1 ('MetaCons "SomeChatUsername" 'PrefixI 'False) (S1 ('MetaSel ('Nothing :: Maybe Symbol) 'NoSourceUnpackedness 'NoSourceStrictness 'DecidedLazy) (Rec0 Text))) | |||||