| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Telegram.Bot.API.Types.TextQuote
Contents
TextQuote
This object contains information about the quoted part of a message that is replied to by the given message.
Constructors
| TextQuote | |
Fields
| |
| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
Telegram.Bot.API.Types.TextQuote
Contents
TextQuoteThis object contains information about the quoted part of a message that is replied to by the given message.
Constructors
| TextQuote | |
Fields
| |